@@ -5,9 +5,11 @@
 "\n"\
 "Contributors:\n"\
 "Alex Foobarian <foobarian@gmail.com>\n"\
-"Guilhem BONNEFILLE  <guilhem.bonnefille@gmail.com>\n"\
+"Bernd Zeimetz <bernd@bzed.de>\n"\
+"Guilhem Bonnefille <guilhem.bonnefille@gmail.com>\n"\
 "Jocelyn Jaubert <jocelyn.jaubert@gmail.com>\n"\
 "Mark Coulter <i_offroad@yahoo.com>\n"\
+"Mathieu Albinet <mathieu17@gmail.com>\n"\
 "Quy Tonthat <qtonthat@gmail.com>\n"\
 "\n"\
 "Few other bugfixes/minor patches from various contributors. See ChangeLog for details.\n"
