@@ -297,12 +297,8 @@ gboolean a_dialog_new_waypoint ( GtkWindow *parent, gchar **dest, VikWaypoint *w
       if ( strlen(constname) == 0 ) /* TODO: other checks (isalpha or whatever ) */
         a_dialog_info_msg ( parent, _("Please enter a name for the waypoint.") );
       else {
-        int i;
         gchar *name = g_strdup ( constname );
 
-        for ( i = strlen ( name ) - 1; i >= 0; i-- )
-          name[i] = toupper(name[i]); /* all caps for stardandization */
-
         if ( g_hash_table_lookup ( waypoints, name ) && !a_dialog_overwrite ( parent, _("The waypoint \"%s\" exists, do you want to overwrite it?"), name ) )
           g_free ( name );
         else
@@ -401,10 +397,6 @@ gchar *a_dialog_new_track ( GtkWindow *parent, GHashTable *tracks )
       a_dialog_info_msg ( parent, _("Please enter a name for the track.") );
     else {
       gchar *name = g_strdup ( constname );
-      gint i;
-
-      for ( i = strlen ( name ) - 1; i >= 0; i-- )
-        name[i] = toupper(name[i]); /* all caps for stardandization */
 
       if ( g_hash_table_lookup( tracks, name ) && !a_dialog_overwrite ( parent, _("The track \"%s\" exists, do you want to overwrite it?"), gtk_entry_get_text ( GTK_ENTRY(entry) ) ) )
       {
@@ -587,7 +579,7 @@ void a_dialog_about ( GtkWindow *parent )
   char *msg = g_markup_printf_escaped (
     _(_("<span font_desc='20' weight='bold'>Viking %s</span>\n\n"
     "GPS Data and Topo Analyzer, Explorer, and Manager.\n\n"
-    "<small>(C) 2003-2007, Evan Battaglia</small>\n\n"
+    "<small>(C) 2003-2008, Evan Battaglia</small>\n\n"
     "<small>Web site: %s</small>")),
     VIKING_VERSION, VIKING_URL);
   GtkWidget *msgbox = gtk_message_dialog_new_with_markup ( parent, 
