@@ -41,7 +41,7 @@ static gboolean expedia_coord_to_mapcoord ( const VikCoord *src, gdouble xzoom,
 static void expedia_mapcoord_to_center_coord ( MapCoord *src, VikCoord *dest );
 static int expedia_download ( MapCoord *src, const gchar *dest_fn );
 
-static DownloadOptions expedia_options = { NULL, 2 };
+static DownloadOptions expedia_options = { NULL, 2, a_check_map_file };
 
 void expedia_init() {
   VikMapsLayer_MapType map_type = { 5, 0, 0, VIK_VIEWPORT_DRAWMODE_EXPEDIA, expedia_coord_to_mapcoord, expedia_mapcoord_to_center_coord, expedia_download };
