@@ -22,17 +22,13 @@
 #ifndef __VIKING_GLOBALS_H
 #define __VIKING_GLOBALS_H
 
+#include <glib.h>
+
 #define PROJECT "Viking"
 #define VIKING_VERSION PACKAGE_VERSION
 #define VIKING_VERSION_NAME "This Name For Rent"
 #define VIKING_URL "http://viking.sf.net/"
 
-#ifdef WINDOWS
-#define access(a,b) _access(a,b)
-#else
-#include <unistd.h>
-#endif
-
 #define ALTI_TO_MPP 1.4017295
 #define MPP_TO_ALTI 0.7134044
 
@@ -48,4 +44,9 @@
 #define MERCLAT(x) (RAD2DEG * log(tan((0.25 * M_PI) + (0.5 * DEG2RAD * (x)))))
 #define DEMERCLAT(x) (RAD2DEG * atan(sinh(DEG2RAD * (x))))
 
+/* Some command line options */
+extern gboolean vik_debug;
+extern gboolean vik_verbose;
+extern gboolean vik_version;
+
 #endif
