@@ -86,6 +86,7 @@ static const char *menu_xml =
 	"      <separator/>"
 	"    </menu>"
 	"    <menu action='Tools'>"
+	"      <menuitem action='Pan'/>"
 	"      <menuitem action='Zoom'/>"
 	"      <menuitem action='Ruler'/>"
 	"    </menu>"
@@ -116,6 +117,7 @@ static const char *menu_xml =
 	"      <separator/>"
 	"    </placeholder>"
 	"    <placeholder name='ToolItems'>"
+	"    <toolitem action='Pan'/>"
 	"    <toolitem action='Zoom'/>"
 	"    <toolitem action='Ruler'/>"
 	"    </placeholder>"
